import { 
  select, 
  csv, 
  scaleLinear, 
  max,
  axisLeft,
  axisBottom,
  format,
  extent
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {

  const title = 'Waiting time vs eruptions duration';
  
  const xValue = d => d.eruptions_duration;
  const xAxisLabel = 'Eruption duration [mins]';
  
  const yValue = d => d.waiting;
  const yAxisLabel = 'Waiting time [mins]';
  
  const circleRadius = 10;
  
  
  const margin = {top: 60, right: 40, bottom: 85, left: 100};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, innerHeight])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.append('g')
    .call(yAxis);
  
  yAxisG.select('.domain').remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
	g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', circleRadius);
  
  g.append('text')
  	.text(title)
  	.attr('y', -10)
  	.attr('class', 'plot-title');
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 70)
  	.text(xAxisLabel)
  	.attr('fill', 'black')
  	.attr('x', innerWidth / 2);
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -65)
  	.text(yAxisLabel)
  	.attr('fill', 'black')
  	.attr('transform', `rotate(-90)`)
  	.attr('x', -innerHeight/2)
  	.attr('text-anchor', 'middle');
  
}

csv('data.csv')
  .then(data => {
    data.forEach(d => {
      d.eruptions_duration = +d.eruptions_duration;
      d.waiting = +d.waiting;
    });
    render(data);
	});



























